Type: Package
Package: Rcompadre
Title: Utilities for using the 'COM(P)ADRE' Matrix Model Database
Version: 1.5.0
Authors@R: c(
    person("Patrick", "Barks", , "barks@biology.sdu.dk", role = "aut",
           comment = c(ORCID = "0000-0002-5947-8151")),
    person("Danny", "Buss", , "dlb50@cam.ac.uk", role = "aut"),
    person("Roberto", "Salguero-Gomez", , "rob.salguero@zoo.ox.ac.uk", role = "aut",
           comment = c(ORCID = "0000-0002-6085-4433")),
    person("Iain", "Stott", , "stott@biology.sdu.dk", role = "aut",
           comment = c(ORCID = "0000-0003-2724-7436")),
    person("William K.", "Petry", , "wpetry@ncsu.edu", role = "aut",
           comment = c(ORCID = "0000-0002-5230-5987")),
    person("Tamora", "James", , "tamoradjames@protonmail.com", role = "aut",
           comment = c(ORCID = "0000-0003-1363-4742")),
    person("Owen", "Jones", , "jones@biology.sdu.dk", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-5720-4686")),
    person("Julia", "Jones", , "juagjones@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0001-9223-1778")),
    person("Gesa", "Römer", , "gesa@biology.sdu.dk", role = "aut",
           comment = c(ORCID = "0000-0002-4859-5870")),
    person("Sam", "Levin", , "levisc8@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-3289-9925"))
  )
Description: Utility functions for interacting with the 'COMPADRE' and
    'COMADRE' databases of matrix population models. Described in Jones et
    al. (2021) <doi:10.1101/2021.04.26.441330>.
License: GPL-3
URL: https://github.com/jonesor/Rcompadre
BugReports: https://github.com/jonesor/Rcompadre/issues
Depends: R (>= 2.10)
Imports: dplyr, methods, popdemo, stats, tibble, utils
Suggests: ggplot2, grDevices, knitr, maps, rcrossref, rmarkdown,
        testthat
VignetteBuilder: knitr
Config/testthat/edition: 3
Config/testthat/parallel: false
Encoding: UTF-8
Language: en-GB
LazyData: true
RoxygenNote: 7.3.2
Collate: 'CompadreDB.R' 'Rcompadre-package.R' 'CompadreDB-Methods.R'
        'CompadreDB-Subsetting.R' 'CompadreDB-Tidyverse.R'
        'CompadreMat.R' 'ClassUnionMethods.R' 'cdb_check_species.R'
        'cdb_build_cdb.R' 'cdb_collapse.R' 'cdb_compare.R'
        'cdb_export_matlab.R' 'cdb_fetch.R' 'cdb_flag.R'
        'cdb_flatten.R' 'cdb_id.R' 'cdb_id_stages.R' 'cdb_id_studies.R'
        'cdb_mean_matF.R' 'cdb_metadata.R' 'cdb_rbind.R'
        'cdb_unflatten.R' 'cdb_unnest.R' 'data.R'
        'mpm_elementwise_apply.R' 'mpm_mean.R' 'mpm_methods.R'
        'mpm_sd.R' 'mpm_median.R' 'string_representation.R' 'zzz.R'
NeedsCompilation: no
Packaged: 2026-04-22 19:40:45 UTC; jones
Author: Patrick Barks [aut] (ORCID: <https://orcid.org/0000-0002-5947-8151>),
  Danny Buss [aut],
  Roberto Salguero-Gomez [aut] (ORCID:
    <https://orcid.org/0000-0002-6085-4433>),
  Iain Stott [aut] (ORCID: <https://orcid.org/0000-0003-2724-7436>),
  William K. Petry [aut] (ORCID: <https://orcid.org/0000-0002-5230-5987>),
  Tamora James [aut] (ORCID: <https://orcid.org/0000-0003-1363-4742>),
  Owen Jones [aut, cre] (ORCID: <https://orcid.org/0000-0001-5720-4686>),
  Julia Jones [aut] (ORCID: <https://orcid.org/0000-0001-9223-1778>),
  Gesa Römer [aut] (ORCID: <https://orcid.org/0000-0002-4859-5870>),
  Sam Levin [aut] (ORCID: <https://orcid.org/0000-0002-3289-9925>)
Maintainer: Owen Jones <jones@biology.sdu.dk>
Repository: CRAN
Date/Publication: 2026-04-23 05:10:41 UTC
Built: R 4.6.0; ; 2026-04-29 01:00:26 UTC; unix
