# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,CompadreDB)
S3method(as_tibble,CompadreDB)
S3method(cbind,CompadreDB)
S3method(dim,CompadreDB)
S3method(droplevels,CompadreDB)
S3method(head,CompadreDB)
S3method(merge,CompadreDB)
S3method(names,CompadreDB)
S3method(print,CompadreDB)
S3method(rbind,CompadreDB)
S3method(subset,CompadreDB)
S3method(tail,CompadreDB)
export(CompadreData)
export(DateCreated)
export(MatrixClassAuthor)
export(MatrixClassNumber)
export(MatrixClassOrganized)
export(NumberAcceptedSpecies)
export(NumberMatrices)
export(NumberStudies)
export(Version)
export(VersionData)
export(as_cdb)
export(cdb_build_cdb)
export(cdb_check_species)
export(cdb_collapse)
export(cdb_compare)
export(cdb_export_matlab)
export(cdb_fetch)
export(cdb_flag)
export(cdb_flatten)
export(cdb_id)
export(cdb_id_stages)
export(cdb_id_studies)
export(cdb_mean_matF)
export(cdb_metadata)
export(cdb_rbind)
export(cdb_unflatten)
export(cdb_unnest)
export(matA)
export(matC)
export(matF)
export(matU)
export(mat_elementwise_apply)
export(mat_mean)
export(mat_median)
export(mat_sd)
export(mat_to_string)
export(matrixClass)
export(mpm_elementwise_apply)
export(mpm_first_active)
export(mpm_has_active)
export(mpm_has_dorm)
export(mpm_has_prop)
export(mpm_mean)
export(mpm_median)
export(mpm_sd)
export(string_to_mat)
export(string_to_vec)
export(vec_to_string)
exportMethods("$")
exportMethods("$<-")
exportMethods("[")
exportMethods("[[")
exportMethods("[[<-")
exportMethods(CompadreData)
exportMethods(DateCreated)
exportMethods(MatrixClassAuthor)
exportMethods(MatrixClassNumber)
exportMethods(MatrixClassOrganized)
exportMethods(NumberAcceptedSpecies)
exportMethods(NumberMatrices)
exportMethods(NumberStudies)
exportMethods(Version)
exportMethods(VersionData)
exportMethods(colnames)
exportMethods(matA)
exportMethods(matC)
exportMethods(matF)
exportMethods(matU)
exportMethods(matrixClass)
exportMethods(mpm_first_active)
exportMethods(mpm_has_active)
exportMethods(mpm_has_dorm)
exportMethods(mpm_has_prop)
importFrom(methods,callNextMethod)
importFrom(methods,hasArg)
importFrom(methods,new)
importFrom(methods,validObject)
importFrom(popdemo,isErgodic)
importFrom(popdemo,isIrreducible)
importFrom(popdemo,isPrimitive)
importFrom(stats,median)
importFrom(stats,sd)
importFrom(tibble,add_column)
importFrom(tibble,as_tibble)
importFrom(utils,head)
importFrom(utils,tail)
